@@ -4,7 +4,7 @@ knitr::opts_chunk$set(
   comment = "##"
 )
 
-## ----chol, cache = TRUE--------------------------------------------------
+## ----chol----------------------------------------------------------------
 library('CholWishart')
 set.seed(20180220)
 A <- stats::rWishart(1,10,5*diag(4))[,,1]
@@ -21,8 +21,15 @@ crossprod(C) %*% crossprod(D) # note: we do not expect C = D^-1, we expect this!
 crossprod(D) %*% A
 crossprod(C) %*% B
 
+## ----pseudo--------------------------------------------------------------
+A <- rPseudoWishart(n = 1, df = 3, Sigma = diag(5))[, , 1]
+A
+qr(A)$rank
+B <- rGenInvWishart(n = 1, df = 3, Sigma = diag(5))[, , 1]
+B
+qr(B)$rank
+
 ## ----density-------------------------------------------------------------
-library('CholWishart')
 dWishart(diag(3), df = 5, 5*diag(3))
 
 dInvWishart(diag(3), df = 5, .2*diag(3))
